*** Settings ***
Documentation       Check that you can list all the @context available in the broker with no previous add @context

Resource            ${EXECDIR}/resources/ApiUtils/jsonldContext.resource
Resource            ${EXECDIR}/resources/AssertionUtils.resource
Resource            ${EXECDIR}/resources/ApiUtils/ContextInformationSubscription.resource

Test Setup          Create initial ImplicitlyCreated @context
Test Teardown       Delete Initial @context Data
Test Template       List @contexts with no previous created @context


*** Variables ***
${subscription_payload_file_path}=      jsonldContext/subscription-with-implicitlycreated-contexts.jsonld
${filename}=                            @context-minimal-valid.json
${reason_200}=                          OK
${reason_204}=                          No Content


*** Test Cases ***    DETAILS    KIND    COUNT
052_06_01 List @contexts with neither details or kind and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    ${EMPTY}    ${EMPTY}    4
052_06_02 List @contexts with no details and kind set to hosted and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    ${EMPTY}    Hosted    0
052_06_03 List @contexts with no details and kind set to cached and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    ${EMPTY}    Cached    3
052_06_04 List @contexts with no details and kind set to implicitlycreated and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    ${EMPTY}    ImplicitlyCreated    1
052_06_05 List @contexts with details set to false and no kind and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    false    ${EMPTY}    4
052_06_06 List @contexts with details set to false and kind equal to hosted and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    false    Hosted    0
052_06_07 List @contexts with details set to false and kind equal to cached and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    false    Cached    3
052_06_08 List @contexts with details set to false and kind equal to implicitlycreated and a created ImplicitlyCreated @context
    [Tags]    ctx-list    5_13_3    since_v1.5.1
    false    ImplicitlyCreated    1


*** Keywords ***
List @contexts with no previous created @context
    [Documentation]    Check that you can list @contexts
    [Arguments]    ${details}    ${kind}    ${count}
    ${response}=    List @contexts    ${details}    ${kind}

    Check Response Status Code    200    ${response.status_code}
    Check Response Reason set to    ${response.reason}    ${reason_200}
    Check Context Response Body Containing a list of identifiers
    ...    response_body=${response.json()}
    ...    expected_length=${count}
    ...    list_contexts=${list_contexts}

Create initial ImplicitlyCreated @context
    ${subscription_payload}=    Load JSON From File    ${EXECDIR}/data/${subscription_payload_file_path}

    ${subscription_id}=    Get Value From JSON    ${subscription_payload}    $..id
    ${subscription_id}=    Get From List    ${subscription_id}    0

    ${list_contexts}=    Get Value From JSON    ${subscription_payload}    $..@context
    ${list_contexts}=    Get From List    ${list_contexts}    0

    ${response}=    Create Subscription
    ...    ${subscription_id}
    ...    ${subscription_payload_file_path}
    ...    ${CONTENT_TYPE_LD_JSON}

    ${response}=    List @contexts    true    ImplicitlyCreated

    Check Response Status Code    200    ${response.status_code}

    ${data}=    Get From List    ${response.json()}    0
    ${implicit_id}=    Get From Dictionary    ${data}    URL
    Append To List    ${list_contexts}    ${implicit_id}

    Check Context Response Body Containing numberOfHits value    ${data}    1

    Set Global Variable    ${implicit_id}
    Set Suite Variable    ${subscription_id}
    Set Suite Variable    ${list_contexts}

Delete Initial @context Data
    Delete Subscription    ${subscription_id}
    FOR    ${uri}    IN    @{list_contexts}
        Log    URI: ${uri}
        Delete a @context    ${uri}
    END
